# -*- coding: utf-8 -*-

import os
from django.conf import settings
from django.utils.text import slugify
from django.utils.translation import gettext_lazy as _


def generate_filename(owner, file_name, prefix_filepath=''):
    owner_path = f"{owner.id}-{slugify(owner.email)}"
    return os.path.join(settings.MEDIA_PRIVATE_ROOT, prefix_filepath, owner_path, file_name)


def write_private_file(owner, file_obj, prefix_filepath=''):
    """
    Upload file on private user dir
    owner: instance of User
    file_obj: instance of file object
    prefix_filepath: prefix path after MEDIA_PRIVATE_ROOT
    """
    filename = generate_filename(owner, file_obj.name, prefix_filepath)
    with open(filename, 'wb') as f:
        try:
            f.write(file_obj.read())
            return True, filename
        except Exception as e:
            return False, str(e)


def delete_private_file(owner, filename, prefix_filepath=''):
    """
    Delete file from private user dir
    owner: instance of User
    filename: file name and path
    prefix_filepath: prefix path after MEDIA_PRIVATE_ROOT
    """
    file_name = os.path.basename(filename)
    filename_new = generate_filename(owner, file_name, prefix_filepath)
    if filename != filename_new:
        return False, _('File not found')
    try:
        os.remove(filename)
        return True, filename
    except Exception as e:
        return False, str(e)
